**Example 1: 新建商户**



Input: 

```
tccli trp CreateMerchant --cli-unfold-argument  \
    --Name demo \
    --Remark demoss \
    --CorpId 10000
```

Output: 
```
{
    "Response": {
        "MerchantId": "awai9jd37ng3de7p3t",
        "RequestId": "233c09fe-7ba7-42e1-8801-acaca177582b"
    }
}
```

